@@ -11,7 +11,7 @@
 
 #include <QComboBox>
 
-#include <AkonadiCore/Tag>
+#include <Akonadi/Tag>
 
 using namespace MailCommon;
 
@@ -39,7 +39,7 @@ QWidget *FilterActionAddTag::createParamWidget(QWidget *parent) const
     }
 
     setParamWidgetValue(mComboBox);
-    connect(mComboBox, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FilterActionAddTag::filterActionModified);
+    connect(mComboBox, &QComboBox::currentIndexChanged, this, &FilterActionAddTag::filterActionModified);
 
     return mComboBox;
 }
@@ -150,3 +150,5 @@ QString FilterActionAddTag::informationAboutNotValidAction() const
     const QString info = name() + QLatin1Char('\n') + i18n("No tag selected.");
     return info;
 }
+
+#include "moc_filteractionaddtag.cpp"
